var class_ogre_1_1_root =
[
    [ "MovableObjectFactoryMap", "class_ogre_1_1_root.html#aa63b41f580aca52c3f35279dd06234fc", null ],
    [ "PluginLibList", "class_ogre_1_1_root.html#a33f7c5af7a51aff1d28a8d7f16253d57", null ],
    [ "PluginInstanceList", "class_ogre_1_1_root.html#a9bd411bb1456e55ca634a67ef003e691", null ],
    [ "MovableObjectFactoryIterator", "class_ogre_1_1_root.html#a724ee7dcbdb7b8052420df2fecd07c0d", null ],
    [ "Root", "class_ogre_1_1_root.html#a293d1580c95101d72f2155e3fe2237bf", null ],
    [ "~Root", "class_ogre_1_1_root.html#ae093f91224577ccb051ac3d8e84c6db8", null ],
    [ "saveConfig", "class_ogre_1_1_root.html#adc6946eb808dd76774d2c95ae1e0c6d9", null ],
    [ "restoreConfig", "class_ogre_1_1_root.html#a816c44429449ce436837f53cd4cb8e93", null ],
    [ "showConfigDialog", "class_ogre_1_1_root.html#aedc76ef3bdc6514bd4655be0d70d6bcd", null ],
    [ "addRenderSystem", "class_ogre_1_1_root.html#ae3d8c9161ddf19b4130813d9b5d51905", null ],
    [ "getAvailableRenderers", "class_ogre_1_1_root.html#a44c5c5f2f90057d57d270c9200cd1588", null ],
    [ "getRenderSystemByName", "class_ogre_1_1_root.html#adaeb26515fba041094510f71fb6757c9", null ],
    [ "setRenderSystem", "class_ogre_1_1_root.html#af768914a0dd431ee442bf83157daf570", null ],
    [ "getRenderSystem", "class_ogre_1_1_root.html#ab8ca3d5abebba7a14650db5f618286d0", null ],
    [ "initialise", "class_ogre_1_1_root.html#a6ab8f204bbfb150ad180eb6e78e4639c", null ],
    [ "isInitialised", "class_ogre_1_1_root.html#a12dc2722de43cb2aa8e93845ea641358", null ],
    [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_root.html#a0c36540d9764ec4e41940423dd0ae88b", null ],
    [ "getRemoveRenderQueueStructuresOnClear", "class_ogre_1_1_root.html#a734be2fb6e01355f328fa5ccd2e737f6", null ],
    [ "setRemoveRenderQueueStructuresOnClear", "class_ogre_1_1_root.html#acdac409627b2920ecb99f4d1cd4af191", null ],
    [ "addSceneManagerFactory", "class_ogre_1_1_root.html#a541c72ca9f592e7a754e751e2b55e934", null ],
    [ "removeSceneManagerFactory", "class_ogre_1_1_root.html#afdf0d57e4f6e80bb519336c56ec23a88", null ],
    [ "getSceneManagerMetaData", "class_ogre_1_1_root.html#a81e1c7b889cd1ab1e17b2d62692a1012", null ],
    [ "getSceneManagerMetaData", "class_ogre_1_1_root.html#a39ba6a3ddd788913af4ee65699d648fd", null ],
    [ "getSceneManagerMetaDataIterator", "class_ogre_1_1_root.html#ad54794875e11d779e264468f805bd00f", null ],
    [ "createSceneManager", "class_ogre_1_1_root.html#a8bb8655f823a98007775f69278c1b0f9", null ],
    [ "createSceneManager", "class_ogre_1_1_root.html#af1dbf157534a776545ea6dcd8a03ee7a", null ],
    [ "createSceneManager", "class_ogre_1_1_root.html#a4fe0c74c398eaff53096838c9dfb341b", null ],
    [ "destroySceneManager", "class_ogre_1_1_root.html#a7ee696cf420c9fa73429b9aed250f6b4", null ],
    [ "getSceneManager", "class_ogre_1_1_root.html#a935897d5b82cc2eedcf0f71109bc810f", null ],
    [ "hasSceneManager", "class_ogre_1_1_root.html#ade931fe093ec242294f8599c1d6e1540", null ],
    [ "getSceneManagerIterator", "class_ogre_1_1_root.html#ad961ad4d34de07ba101ea92e33007a7b", null ],
    [ "getSceneManagers", "class_ogre_1_1_root.html#ad896d09263f5c4fee1c7f619aea0307b", null ],
    [ "getTextureManager", "class_ogre_1_1_root.html#a55641d6a52ee618286bba6e9892e8d78", null ],
    [ "getMeshManager", "class_ogre_1_1_root.html#a3372db66af0d91da9184af90c1a68528", null ],
    [ "addFrameListener", "class_ogre_1_1_root.html#aed3244a81b1c1cec76c675f8e62d7f5e", null ],
    [ "removeFrameListener", "class_ogre_1_1_root.html#aba900bb388dd68af993df311076a9205", null ],
    [ "queueEndRendering", "class_ogre_1_1_root.html#acf11f973aaa634e9fc95106285fad430", null ],
    [ "endRenderingQueued", "class_ogre_1_1_root.html#a5520d8d9e91c82d3d7ed273f02461edd", null ],
    [ "startRendering", "class_ogre_1_1_root.html#a8eda253befda1255cbfd3b298f62449e", null ],
    [ "renderOneFrame", "class_ogre_1_1_root.html#aeaad25268c0ad8007ce8961a32242c77", null ],
    [ "renderOneFrame", "class_ogre_1_1_root.html#a7820badfeef2fb9994ea9de17facb218", null ],
    [ "shutdown", "class_ogre_1_1_root.html#adc677530cc7ef50fbd0e37d75c02e16b", null ],
    [ "createFileStream", "class_ogre_1_1_root.html#a6461e7f5423d060704cc9548a1b52b7a", null ],
    [ "openFileStream", "class_ogre_1_1_root.html#a7ff564512e4873f5ea27c36adb3face1", null ],
    [ "convertColourValue", "class_ogre_1_1_root.html#a58fb421c717de3fcb51b1cf93da813ff", null ],
    [ "getAutoCreatedWindow", "class_ogre_1_1_root.html#a7f5006f1ef629981b96252860beef846", null ],
    [ "createRenderWindow", "class_ogre_1_1_root.html#a537b7d1d0937f799cfe4936f6b672620", null ],
    [ "createRenderWindow", "class_ogre_1_1_root.html#a4de843c1727c6671171c4f072bba7324", null ],
    [ "createRenderWindows", "class_ogre_1_1_root.html#aeda5e7e1148739e9fbbb2113bb47a6e8", null ],
    [ "detachRenderTarget", "class_ogre_1_1_root.html#aa162fb6b49c21c8f17c7a2a05a6c537e", null ],
    [ "detachRenderTarget", "class_ogre_1_1_root.html#afe02a03ca34a3836c36f0b6753b617f8", null ],
    [ "destroyRenderTarget", "class_ogre_1_1_root.html#a9c063121d67ba39f658295b3ccefb37a", null ],
    [ "destroyRenderTarget", "class_ogre_1_1_root.html#acb88716975857a8e39f879bfd87180b9", null ],
    [ "getRenderTarget", "class_ogre_1_1_root.html#a7bc9f24bec1e8b69a80d246e68bd8bee", null ],
    [ "loadPlugin", "class_ogre_1_1_root.html#af0744e85bddb05885a91809bcdf8f864", null ],
    [ "unloadPlugin", "class_ogre_1_1_root.html#a9e2492db70157da036a814c84e516500", null ],
    [ "installPlugin", "class_ogre_1_1_root.html#a5ea47cd9c094644e1abac7607e1922fd", null ],
    [ "uninstallPlugin", "class_ogre_1_1_root.html#a23417d6cbe7aeeafcc6a1a146a5e7b95", null ],
    [ "getInstalledPlugins", "class_ogre_1_1_root.html#a56808b5253027913a78d254f6421d908", null ],
    [ "getTimer", "class_ogre_1_1_root.html#a507ed05fd59e0697797b8c9c9038448f", null ],
    [ "_fireFrameStarted", "class_ogre_1_1_root.html#a194d3177b24dae7d73255268773a54b3", null ],
    [ "_fireFrameRenderingQueued", "class_ogre_1_1_root.html#a23fd83ef996349d5151cd93ca4908d36", null ],
    [ "_fireFrameEnded", "class_ogre_1_1_root.html#a01d3244dcf290c2db36aea6b0c63616a", null ],
    [ "_fireFrameStarted", "class_ogre_1_1_root.html#af747fc0427276e6c6936dd6a5ca01e87", null ],
    [ "_fireFrameRenderingQueued", "class_ogre_1_1_root.html#a15166e7cc1e879b71948665737e79ce6", null ],
    [ "_fireFrameEnded", "class_ogre_1_1_root.html#a57ec49d0fd19402ea8a4336f53ab62b4", null ],
    [ "getNextFrameNumber", "class_ogre_1_1_root.html#aa0cf5300f2f1893c1eb8749ae7d074f0", null ],
    [ "_getCurrentSceneManager", "class_ogre_1_1_root.html#a883fd5c2376cec804e00265ad71e1d2e", null ],
    [ "_pushCurrentSceneManager", "class_ogre_1_1_root.html#a14ab7036973eb56ee4e1ad10304d9b12", null ],
    [ "_popCurrentSceneManager", "class_ogre_1_1_root.html#a16b5488539651d697d0a4dd5cdbdd4c3", null ],
    [ "_updateAllRenderTargets", "class_ogre_1_1_root.html#a24559fa6a4f1772c7518fcb0911278f4", null ],
    [ "_updateAllRenderTargets", "class_ogre_1_1_root.html#aba26bc9123d8725d971e458e48c2694f", null ],
    [ "createRenderQueueInvocationSequence", "class_ogre_1_1_root.html#a73bbafca83dfb0f6971162efc3710977", null ],
    [ "getRenderQueueInvocationSequence", "class_ogre_1_1_root.html#ac2ba507a55bfd6c69552e3d74e1ce7aa", null ],
    [ "destroyRenderQueueInvocationSequence", "class_ogre_1_1_root.html#a4ab34dbd132ad5cae81d7753af244f2a", null ],
    [ "destroyAllRenderQueueInvocationSequences", "class_ogre_1_1_root.html#acfa8a88f7186f9a665f733e7021c8c34", null ],
    [ "getSingleton", "class_ogre_1_1_root.html#a6c8959a647a86d6732a8a32f57b6a6ee", null ],
    [ "getSingletonPtr", "class_ogre_1_1_root.html#a0813c15b258db16ef212dba53b72c3e4", null ],
    [ "clearEventTimes", "class_ogre_1_1_root.html#a2afff4a877a26bff8b47d32f9dcc15a8", null ],
    [ "setFrameSmoothingPeriod", "class_ogre_1_1_root.html#a1f045bf046a75d65e6ddc71f4ebe0b2c", null ],
    [ "getFrameSmoothingPeriod", "class_ogre_1_1_root.html#abe00e99a9ee49d6f095f943c42ae512e", null ],
    [ "addMovableObjectFactory", "class_ogre_1_1_root.html#a261189545f730e6243418d93cebfb75b", null ],
    [ "removeMovableObjectFactory", "class_ogre_1_1_root.html#a5dcfb7ee8fb1473fdc973752bc9452b4", null ],
    [ "hasMovableObjectFactory", "class_ogre_1_1_root.html#a90c3f8c5e515282b8aa0fe0352ddc934", null ],
    [ "getMovableObjectFactory", "class_ogre_1_1_root.html#ab89302520cbbe6d78d25e325081ea906", null ],
    [ "_allocateNextMovableObjectTypeFlag", "class_ogre_1_1_root.html#a3840c316ccddef1ccadf51325ad72ee2", null ],
    [ "getMovableObjectFactories", "class_ogre_1_1_root.html#aac9810b87f46b33844f4d55828cb74fc", null ],
    [ "getMovableObjectFactoryIterator", "class_ogre_1_1_root.html#a18d21240d53ca480b6c122d80185ac3b", null ],
    [ "getDisplayMonitorCount", "class_ogre_1_1_root.html#a14e8da7f3396ba7d22940006c6cba55d", null ],
    [ "getWorkQueue", "class_ogre_1_1_root.html#aadb91b200119d99eac7db174424f6634", null ],
    [ "setWorkQueue", "class_ogre_1_1_root.html#afdca040bfe42cac1b33402f37023b121", null ],
    [ "setBlendIndicesGpuRedundant", "class_ogre_1_1_root.html#a9c610fa759978755ffd9da222fe68b3e", null ],
    [ "isBlendIndicesGpuRedundant", "class_ogre_1_1_root.html#a0a10213bc5e0af9946cc295e84331d37", null ],
    [ "setBlendWeightsGpuRedundant", "class_ogre_1_1_root.html#ab7360b80fdc4eeb6bc63ff594c04bd04", null ],
    [ "isBlendWeightsGpuRedundant", "class_ogre_1_1_root.html#ab5b391ac4b40774d1d77a339140bc954", null ],
    [ "setDefaultMinPixelSize", "class_ogre_1_1_root.html#aa44a0398484e6efc3d13c590f02b0783", null ],
    [ "getDefaultMinPixelSize", "class_ogre_1_1_root.html#ab6d87c0af70d247b8809cf61e9482840", null ],
    [ "RenderSystem", "class_ogre_1_1_root.html#a06b786d8e0847dfe9cc15e1dea308fcd", null ]
];